<?php
// +---------------------------------------------------------------------------+
// | amz plugin                                                                |
// +---------------------------------------------------------------------------+
// | install.php                                                               |
// |                                                                           |
// | This file installs the data structures for the amz plugin for Geeklog.    |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2005 Andy Maloney [amaloney@users.sf.net]                   |
// |                                                                           |
// | Constructed with the Universal Plugin                                     |
// | Copyright (C) 2002 by the following authors:                              |
// | Tom Willett                 -    twillett@users.sourceforge.net           |
// | Blaine Lang                 -    langmail@sympatico.ca                    |
// | The Universal Plugin is based on prior work by:                           |
// | Tony Bibbs                  -    tony@tonybibbs.com                       |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+

require_once( '../../../lib-common.php' );
require_once( $_CONF['path'] . 'plugins/amz/config.php' );
require_once( $_CONF['path'] . 'plugins/amz/functions.inc' );

// Only let Root users access this page
if ( !SEC_inGroup( 'Root' ) )
{
    COM_errorLog( "Someone has tried to illegally access the amz install page.  "
    	. "User id: {$_USER['uid']}, Username: {$_USER['username']}, IP: {$_SERVER['REMOTE_ADDR']}",1 );

    echo COM_siteHeader();
    echo COM_startBlock( $LANG_AZ00['access_denied'] );
    echo $LANG_AZ00['access_denied_msg'];
    echo COM_endBlock();
    echo COM_siteFooter( true );
    exit;
}

$pi_name = 'amz';
$pi_version = plugin_chkVersion_amz();
$gl_version = '1.3.11';
$pi_url = 'http://imol.gotdns.com';      // Plugin Homepage

//
// Security Feature to add

$NEWFEATURE = array();
$NEWFEATURE['amz.admin'] = "amz Admin";

 
/**
* Puts the datastructures for this plugin into the Geeklog database
*
* Note: Corresponding uninstall routine is in functions.inc
* 
* @return   boolean True if successful False otherwise
*
*/
function plugin_install_amz()
{
    global $pi_name, $pi_version, $gl_version, $pi_url, $NEWTABLE, $DEFVALUES, $NEWFEATURE;
    global $_TABLES, $_CONF;

    COM_errorLog( "Installing the amz plugin", 1 );

    // Create the Plugins Tables
    AMZ_createDatabaseStructures();
    
    // Create the plugin admin security group
    COM_errorLog( "Creating amz admin group",  1 );
    DB_query( "INSERT INTO {$_TABLES['groups']} (grp_name, grp_descr)
    			VALUES ('$pi_name Admin', 'Users in this group can administer the $pi_name plugin')", 1 );
    
    if ( DB_error() )
        return false;

    $group_id = DB_insertId();
    
    // Save the grp id for later uninstall
    COM_errorLog( 'Saving group_id to vars table for use during uninstall', 1 );
    DB_query( "INSERT INTO {$_TABLES['vars']} VALUES ('{$pi_name}_gid', $group_id)", 1 );
    
    if ( DB_error() )
        return false;
    
    // Add plugin Features
    foreach ($NEWFEATURE as $feature => $desc)
    {
        COM_errorLog( "Adding $feature feature", 1 );
        DB_query( "INSERT INTO {$_TABLES['features']} (ft_name, ft_descr) VALUES ('$feature','$desc')", 1 );
        
        if ( DB_error() )
        {
            COM_errorLog( "Failure adding $feature feature", 1 );
            return false;
        }
        
        $feat_id = DB_insertId();
        
        COM_errorLog( "Adding $feature feature to admin group", 1 );
        DB_query( "INSERT INTO {$_TABLES['access']} (acc_ft_id, acc_grp_id) VALUES ($feat_id, $group_id)" );
        
        if ( DB_error() )
        {
            COM_errorLog( "Failure adding $feature feature to admin group", 1 );
            return false;
        }
    }        
    
    // add the block
	$sql = "INSERT INTO {$_TABLES['blocks']}
		( is_enabled, name, type, title, blockorder, onleft, phpblockfn, group_id, owner_id )
		VALUES( 1, 'amz_block', 'phpblock', 'Search Amazon', 10, 0, 'phpblock_amzblock', {$group_id}, 2 )
		";

	DB_query( $sql, 1 );
    if ( DB_error() )
    {
		COM_errorLog( "Failure adding block", 1 );
		return false;
    }
	
    // OK, now give Root users access to this plugin now! NOTE: Root group should always be 1
    COM_errorLog( "Giving all users in Root group access to amz admin group", 1 );
    DB_query( "INSERT INTO {$_TABLES['group_assignments']} VALUES ($group_id, NULL, 1)" );
    
    if ( DB_error() )
        return false;

    // Register the plugin with Geeklog
    COM_errorLog( "Registering amz plugin with Geeklog", 1 );
    DB_query( "DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'amz'");
    DB_query( "INSERT INTO {$_TABLES['plugins']} (pi_name, pi_version, pi_gl_version, pi_homepage, pi_enabled) 
    			VALUES ('$pi_name', '$pi_version', '$gl_version', '$pi_url', 1)" );

    if ( DB_error() )
        return false;

    COM_errorLog( "Succesfully installed the amz plugin!", 1 );
    
    return true;
}

function AMZ_createDatabaseStructures()
{
    global $_CONF, $_DB, $_TABLES;

    $_DB->setDisplayError( true );

	// default xsl file
	$xsl_URL = $_CONF['site_url'] . "/amz/xsl/item-search.xsl";

	require_once( $_CONF['path'] . 'plugins/amz/sql/amz.php');

	// build tables
	for ( $i = 1; $i <= count( $_SQL ); $i++ )
	{
		DB_query( current( $_SQL ) );
		next( $_SQL );
	}

	// insert data
    for ( $i = 1; $i <= count( $_DATA ); $i++ )
    {
        DB_query( current( $_DATA ) );
        next( $_DATA );
    }
}

/* 
* Main Function
*/

$display = COM_siteHeader();
$display .= COM_startBlock( $LANG_AZ00['install_header'] );

if ( $action == 'install' )
{
	$img_url = $_CONF['site_url'] . '/amz/images/amz.gif';

	$display .= "<img align=left src=\"$img_url\" alt='amz icon' width=48 height=48>";
	
    if ( plugin_install_amz() )
    {
        $blockManager = $_CONF['site_admin_url'] . '/block.php';
        $admin_url = $_CONF['site_admin_url'] . '/plugins/amz/index.php';
        $readme_url = $_CONF['site_admin_url'] . '/plugins/amz/readme.html';

        $display .= '<p>I have created all the necessary tables and activated the Amazon Search block on the right hand side. ';
        $display .= "If you want it on the left, use the <a href=\"{$blockManager}\">Block Manager</a> to move it.";

		$display .= "<p>To configure the Amazon plugin, go to the <a href=\"$admin_url\">admin page</a>.
			Information about the various configuration options	may be found in the 
			<a href=\"{$readme_url}#config\">README file</a>.";
    }
    else
    {
		plugin_uninstall_amz();
        $display .= '<p>' . $LANG_AZ00['install_failed'];
    }
}

$display .= COM_endBlock();
$display .= COM_siteFooter( true );

echo $display;
?>
