<?php
// +---------------------------------------------------------------------------+
// | amz plugin                                                                |
// +---------------------------------------------------------------------------+
// | functions.inc                                                             |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2005 Andy Maloney [amaloney@users.sf.net]                   |
// |                                                                           |
// | Constructed with the Universal Plugin                                     |
// | Copyright (C) 2002 by the following authors:                              |
// | Tom Willett                 -    twillett@users.sourceforge.net           |
// | Blaine Lang                 -    langmail@sympatico.ca                    |
// | The Universal Plugin is based on prior work by:                           |
// | Tony Bibbs                  -    tony@tonybibbs.com                       |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+

/**
* Language file Include
*/
$langfile = $_CONF['path'] . 'plugins/amz/language/' . $_CONF['language'] . '.php';

if ( file_exists( $langfile ) ) 
    include_once( $langfile );
else 
    include_once( $_CONF['path'] . 'plugins/amz/language/english.php' );

/*
* Include amz config file
*/
require_once( $_CONF['path'] . 'plugins/amz/config.php' );

AMZ_readCookie();

// +---------------------------------------------------------------------------+
// | Geeklog Plugin API Implementations                                        |
// +---------------------------------------------------------------------------+

/**
 * Returns the current plugin code version
 * 
 * @return string    plugin version
*/
function plugin_chkVersion_amz()
{
	return '1.3.0';
}

/**
* This will put an option for the plugin in the command and control block on moderation.php
*
* Add the plugin name, icon and link to the command and control block in moderation.php
*
* @return   array   Array containing (plugin name, admin url, url of plugin icon)
*
*/
function plugin_cclabel_amz() 
{
    global $_CONF;

    return array( 'Amazon',$_CONF['site_admin_url'] . '/plugins/amz/index.php',$_CONF['site_url'] . '/amz/images/amz.gif' );
}

/**
* Returns the administrative option for this plugin
*
* Adds the plugin to the Admin menu
*
* Universal Plugin:  Modify/Uncomment use it
*
* @return   array   Array containing (plugin name, plugin admin url, # of items in plugin or '')
*
*/
function plugin_getadminoption_amz() 
{
	global $_CONF, $_TABLES;

	if ( SEC_hasRights( 'amz.admin' ) )
		return array( 'Amazon', $_CONF['site_admin_url'] . '/plugins/amz/index.php', '' );
}

/**
 * Upgrade the plugin
*/
function plugin_upgrade_amz()
{
	global $_TABLES;
	
	$res = DB_query( "SELECT pi_version FROM {$_TABLES['plugins']} WHERE pi_name = 'amz' LIMIT 1" );
	$row = DB_fetchArray( $res, false );
	
	COM_errorLog( "Updating amz plugin from v" . $row['pi_version'] . ' to v' . plugin_chkVersion_amz(), 1 );
	
	return AMZ_doDatabaseUpgrades( $row['pi_version'] );
}

function AMZ_doDatabaseUpgrades( $current_amz_version )
{
	global $_TABLES, $_CONF, $_DB;

	$_DB->setDisplayError( true );


	$done = false;

	while ( $done == false )
	{
		switch ( $current_amz_version )
		{
			case '1.0.0':
				require_once( $_CONF['path'] . 'plugins/amz/sql/updates/amz_1.0.0_to_1.1.0.php' );

				for ( $i = 1; $i <= count( $_SQL ); $i++ )
				{
					DB_query( current( $_SQL ) );
					next( $_SQL );
				}

				$current_amz_version = '1.1.0';
				break;
			
			case '1.1.0':
				require_once( $_CONF['path'] . 'plugins/amz/sql/updates/amz_1.1.0_to_1.2.0.php' );

				for ( $i = 1; $i <= count( $_SQL ); $i++ )
				{
					DB_query( current( $_SQL ) );
					next( $_SQL );
				}

				$current_amz_version = '1.2.0';
				break;
			
			case '1.2.0':
			case '1.2.1':
				require_once( $_CONF['path'] . 'plugins/amz/sql/updates/amz_1.2.1_to_1.3.0.php' );

				for ( $i = 1; $i <= count( $_SQL ); $i++ )
				{
					DB_query( current( $_SQL ) );
					next( $_SQL );
				}

				$current_amz_version = '1.3.0';
				break;
			
			default:
				$done = true;
				break;
		}
	}

	DB_query( "UPDATE {$_TABLES['plugins']} SET pi_version = '{$current_amz_version}' WHERE pi_name = 'amz' LIMIT 1" );

	$_DB->setDisplayError( false );
	
	return true;
}

/**
* Removes the datastructures for this plugin from the Geeklog database.
*
*/  
function plugin_uninstall_amz( $installCheck = '' )
{
    global $_TABLES, $LANG_AZ00;

    $FEATURES = array ( 'amz.admin');
    $TABLES = array( 'amz_servers', 'amz_prefs' );
    
    // Check and see if plugin is still enabled - if so display warning and exit
    if ( $installCheck != '' && DB_getItem( $_TABLES['plugins'],'pi_enabled', 'pi_name = "amz"' ) )
    {
	    COM_errorLog( "Plugin is installed and enabled. Disable first if you want to remove it", 1 );
		$display .= COM_startBlock( $LANG_AZ00['warning'] );
		$display .= $LANG_AZ00['enabled'];
		$display .= COM_endBlock();
		echo $display;
		return false;
	}
    	
	// Ok to proceed and delete plugin

    // Unregister the plugin with Geeklog
    COM_errorLog( 'Deregistering the amz plugin from Geeklog', 1 );
    DB_query( "DELETE FROM {$_TABLES['plugins']} WHERE pi_name = 'amz'", 1 );

    // Drop amz tables
    foreach ( $TABLES as $table )
    {
        $t = $_TABLES["$table"];
        COM_errorLog( "Removing table $t", 1 );
        DB_query( "DROP TABLE $t", 1 );
    }

    // remove block
    COM_errorLog( "Removing amz block", 1 );
    DB_query( "DELETE FROM {$_TABLES['blocks']} WHERE name='amz_block' LIMIT 1", 1 );
 
    // Remove Security for this plugin
    $grp_id = DB_getItem( $_TABLES['vars'], 'value', "name = 'amz_gid'" );
    
    COM_errorLog( "Removing amz Admin Group", 1 );
    DB_query( "DELETE FROM {$_TABLES['groups']} WHERE grp_id = $grp_id", 1 );
    DB_query( "DELETE FROM {$_TABLES['vars']} WHERE name = 'amz_gid'" );
    
    COM_errorLog( "Removing root users from admin of amz" );
    DB_query( "DELETE FROM {$_TABLES['group_assignments']} WHERE ug_main_grp_id = $grp_id", 1 );
    
    // Remove all the associated features -- access rights
    foreach ( $FEATURES as $feature )
    {
        COM_errorLog( "Removing $feature feature and rights to it", 1 );
        $feat_id = DB_getItem( $_TABLES['features'], 'ft_id', "ft_name = '$feature'" );
        DB_query( "DELETE FROM {$_TABLES['access']} WHERE acc_ft_id = $feat_id", 1 );
        DB_query( "DELETE FROM {$_TABLES['features']} WHERE ft_id = $feat_id", 1 );
    }
        
    COM_errorLog( 'amz plugin removed', 1 );
    return true;
}

//-------------------------------

function AMZ_readPrefs()
{
	global $_AMZ_PREFS, $_TABLES;
	
	// read prefs
	$res = DB_query( "SELECT * from {$_TABLES['amz_prefs']}", 1 );
	
	$_AMZ_PREFS = array();
	
	if ( DB_error() )
	{
		// IF we are here, then the user is likely installing the plugin, so return false
		return false;
	}
	else
	{
		while ( $row = mysql_fetch_assoc( $res ) )
		{
			$_AMZ_PREFS[$row['name']] = $row['value'];
		}
	}
	
	return true;
}

function AMZ_readCookie()
{
	global $_AMZ_PREFS, $cookie_data, $_TABLES;
	
	if ( isset( $_COOKIE['amz_pref'] ) )
	{
		$string = stripslashes( $_COOKIE['amz_pref'] );
		
		$cookie_data = unserialize( $string );
	}
	else if ( AMZ_readPrefs() )
	{
		$cookie_data['server'] = $_AMZ_PREFS['default_server'];
		$cookie_data['category'] = $_AMZ_PREFS['default_category'];

		// keyword is a special case - we don't want to show the default search term in the block,
		//	so we will default to the db keyword in search.php
		$cookie_data['keyword'] = '';	
	}
}

function AMZ_writeCookie()
{
	global $_AMZ_PREFS, $cookie_data;

	if ( $_AMZ_PREFS['use_cookie'] == 0 )
		return;
		
	$cookie_data_expire = 60 * 60 * 24 * 60;
	
	$string = serialize( $cookie_data );
	
	setcookie( 'amz_pref', $string, time() + $cookie_data_expire, '/' );
}

function phpblock_amzblock()
{
	global $cookie_data, $_CONF, $_TABLES;


	$display = '<div>';
	$display .= '<form action="' . $_CONF['site_url'] . '/amz/search.php">';
	$display .= '<div style="text-align: left;">';
	$display .= 'amazon.<select name="a_server">';

	$id = $cookie_data['server'];

	$display .= '<option value="com"' . ($id == 'com' ? selected : '') . '>com&nbsp;&nbsp;</option>';
	$display .= '<option value="ca"' . ($id == 'ca' ? selected : '') . '>ca</option>';
	$display .= '<option value="uk"' . ($id == 'uk' ? selected : '') . '>uk</option>';
	$display .= '<option value="fr"' . ($id == 'fr' ? selected : '') . '>fr</option>';
	$display .= '<option value="de"' . ($id == 'de' ? selected : '') . '>de</option>';
	$display .= '<option value="jp"' . ($id == 'jp' ? selected : '') . '>jp</option>';
	$display .= '</select>';
	$display .= '</div>';
	$display .= '<p><input type="text" name="keyword" size="17" value="' . $cookie_data['keyword'] . '">';

	$display .= '<input type="image" value="Go" name="Submit" '
				. 'src="' . $_CONF['site_url'] . '/amz/images/amazon-go.gif" '
                . 'style="border: 0; vertical-align: middle; width: 21px; height: 21px;">';
	$display .= '</form>';
	$display .= '<input type="hidden" name="category" value="' . $cookie_data['category'] . '">';
	$display .= '</div>';
	
	return $display;
}
?>
